@@ -1,6 +1,5 @@
-from mitama.http import get_session, Response
+from mitama.http import Response, get_session
+
 
 async def home(request):
     return Response()
-
-
